==> haskell-fingertree-0.1.1.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.1.0
id: fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
key: fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
license: BSD3
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
abi: fe17c4f31be0e934ab503a72bf6ee7b1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fingertree-0.1.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/fingertree-0.1.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/fingertree-0.1.1.0
hs-libraries: HSfingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.1.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.1.0
id: fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
key: fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
license: BSD3
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
abi: de55bc71a2501186b16af1e3f45f546a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/fingertree-0.1.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/fingertree-0.1.1.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/fingertree-0.1.1.0
hs-libraries: HSfingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
